@@ -1,8 +1,13 @@
 #!/bin/bash
 ##configure.inのAC_INIT(jobarranger, x.x.x) Version　変更
 
-aclocal -I m4
+rm -rf autom4te.cache
+
+set -a
+. ./.env
+set +a
+
+aclocal --system-acdir=/usr/share/aclocal
 autoconf
 autoheader
-automake -a
-automake
\ No newline at end of file
+automake -a
\ No newline at end of file
